@@ -179,6 +179,7 @@ class UploadPhotoMixin:
         upload_id: str = "",
         usertags: List[Usertag] = [],
         location: Location = None,
+        extra_data: Dict[str, str] = {},
     ) -> Media:
         """
         Upload photo and configure to feed
@@ -195,6 +196,8 @@ class UploadPhotoMixin:
             List of users to be tagged on this upload, default is empty list.
         location: Location, optional
             Location tag for this upload, default is None
+        extra_data: Dict[str, str], optional
+            Dict of extra data, if you need to add your params, like {"share_to_facebook": 1}.
 
         Returns
         -------
@@ -208,6 +211,7 @@ class UploadPhotoMixin:
             time.sleep(3)
             if self.photo_configure(
                 upload_id, width, height, caption, usertags, location,
+                extra_data=extra_data
             ):
                 media = self.last_json.get("media")
                 self.expose()
@@ -224,6 +228,7 @@ class UploadPhotoMixin:
         caption: str,
         usertags: List[Usertag] = [],
         location: Location = None,
+        extra_data: Dict[str, str] = {},
     ) -> Dict:
         """
         Post Configure Photo (send caption to Instagram)
@@ -242,6 +247,8 @@ class UploadPhotoMixin:
             List of users to be tagged on this upload, default is empty list.
         location: Location, optional
             Location tag for this upload, default is None
+        extra_data: Dict[str, str], optional
+            Dict of extra data, if you need to add your params, like {"share_to_facebook": 1}.
 
         Returns
         -------
@@ -276,6 +283,7 @@ class UploadPhotoMixin:
                 "crop_zoom": 1.0,
             },
             "extra": {"source_width": width, "source_height": height},
+            **extra_data
         }
         return self.private_request("media/configure/", self.with_default_data(data))
 
@@ -289,6 +297,7 @@ class UploadPhotoMixin:
         links: List[StoryLink] = [],
         hashtags: List[StoryHashtag] = [],
         stickers: List[StorySticker] = [],
+        extra_data: Dict[str, str] = {},
     ) -> Story:
         """
         Upload photo as a story and configure it
@@ -311,6 +320,8 @@ class UploadPhotoMixin:
             List of hashtags to be tagged on this upload, default is empty list.
         stickers: List[StorySticker], optional
             List of stickers to be tagged on this upload, default is empty list.
+        extra_data: Dict[str, str], optional
+            Dict of extra data, if you need to add your params, like {"share_to_facebook": 1}.
 
         Returns
         -------
@@ -332,6 +343,7 @@ class UploadPhotoMixin:
                 links,
                 hashtags,
                 stickers,
+                extra_data=extra_data
             ):
                 media = self.last_json.get("media")
                 self.expose()
@@ -383,7 +395,7 @@ class UploadPhotoMixin:
             List of hashtags to be tagged on this upload, default is empty list.
         stickers: List[StorySticker], optional
             List of stickers to be tagged on this upload, default is empty list.
-        extra_data: List[str, str], optional
+        extra_data: Dict[str, str], optional
             Dict of extra data, if you need to add your params, like {"share_to_facebook": 1}.
 
         Returns
